@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: cfgfile.c,v 1.28 2000/02/17 20:26:53 bazsi Exp $
+ * $Id: cfgfile.c,v 1.29 2000/02/22 17:50:29 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -213,6 +213,7 @@ static int do_destroy_config(struct syslog_config *self, struct persistent_confi
 
 extern FILE *yyin;
 extern int yyparse();
+extern void lex_init(FILE *);
 extern int yydebug;
 extern int linenum;
 
@@ -237,8 +238,7 @@ struct syslog_config *make_syslog_config(const char *name, struct io_backend *ba
 	self->gc_idle_threshold = 100;
 	self->gc_busy_threshold = 3000;
 	if ((cfg = fopen(name, "r")) != NULL) {
-		linenum = 1;
-		yyin = cfg;
+		lex_init(cfg);
 		res = yyparse();
 		fclose(cfg);
 		if (!res) {
