@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: filters.c,v 1.10 1999/11/16 17:30:05 bazsi Exp $
+ * $Id: filters.c,v 1.11 2000/02/25 12:11:42 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -63,7 +63,7 @@ static int do_filter_and(struct filter_expr_node *c,
 {
 	CAST(filter_expr_op, self, c);
 
-	return FILTER_RULE_EVAL(self->left, rule, log) && FILTER_RULE_EVAL(self->right, rule, log);
+	return (FILTER_RULE_EVAL(self->left, rule, log) && FILTER_RULE_EVAL(self->right, rule, log)) ^ c->comp;
 }
 
 struct filter_expr_node *make_filter_and(struct filter_expr_node *l, struct filter_expr_node *r)
@@ -82,7 +82,7 @@ static int do_filter_or(struct filter_expr_node *c,
 {
 	CAST(filter_expr_op, self, c);
 
-	return FILTER_RULE_EVAL(self->left, rule, log) || FILTER_RULE_EVAL(self->right, rule, log);
+	return (FILTER_RULE_EVAL(self->left, rule, log) || FILTER_RULE_EVAL(self->right, rule, log)) ^ c->comp;
 }
  
 struct filter_expr_node *make_filter_or(struct filter_expr_node *l, struct filter_expr_node *r)
@@ -100,24 +100,25 @@ struct filter_expr_node *make_filter_or(struct filter_expr_node *l, struct filte
      (name filter_expr_pri)
      (super filter_expr_node)
      (vars
-       (mask simple UINT32)
-       (valid simple UINT32)
-       (values pointer (simple "struct sl_name"))
-       (cmp simple int)))
+       (valid simple UINT32)))
 */
 
-static int do_filter_pri(struct filter_expr_node *c, 
-			struct log_filter *rule UNUSED,
+static int do_filter_fac(struct filter_expr_node *c, 
+			 struct log_filter *rule UNUSED,
 			 struct log_info *log)
 {
 	CAST(filter_expr_pri, self, c);
-	UINT32 pri = log->pri & self->mask;
+	UINT32 pri = log->pri & LOG_FACMASK;
 	int i;
 	UINT32 bits = self->valid;
-
-	for (i = 0; bits && self->values[i].name; i++, bits >>= 1) {
-		if ((bits & 1) && self->values[i].value == pri) {
-			return !self->super.comp;
+	if (bits & 0x80000000) {
+		return ((bits & ~0x80000000) == pri) ^ self->super.comp;
+	}
+	else {
+		for (i = 0; bits && sl_facilities[i].name; i++, bits >>= 1) {
+			if ((bits & 1) && sl_facilities[i].value == pri) {
+				return !self->super.comp;
+			}
 		}
 	}
 	return self->super.comp;
@@ -127,20 +128,27 @@ struct filter_expr_node *make_filter_facility(UINT32 valid)
 {
 	NEW(filter_expr_pri, self);
 
-	self->super.eval = do_filter_pri;
-	self->mask = LOG_FACMASK;
-	self->values = sl_facilities;
+	self->super.eval = do_filter_fac;
 	self->valid = valid;
 	return &self->super;
 }
 
+static int do_filter_lev(struct filter_expr_node *c, 
+			 struct log_filter *rule UNUSED,
+			 struct log_info *log)
+{
+	CAST(filter_expr_pri, self, c);
+	UINT32 pri = log->pri & LOG_PRIMASK;
+
+	return (!!(self->valid & (1 << pri))) ^ self->super.comp;
+}
+
+
 struct filter_expr_node *make_filter_level(UINT32 valid)
 {
 	NEW(filter_expr_pri, self);
 
-	self->super.eval = do_filter_pri;
-	self->mask = LOG_PRIMASK;
-	self->values = sl_levels;
+	self->super.eval = do_filter_lev;
 	self->valid = valid;
 	return &self->super;
 }
@@ -268,7 +276,7 @@ static int do_filter_call(struct filter_expr_node *c,
 		self->call_rule = p;
 	}
 	if (self->call_rule)
-		return FILTER_RULE_EVAL(self->call_rule->root, self->call_rule, log);
+		return (FILTER_RULE_EVAL(self->call_rule->root, self->call_rule, log)) ^ c->comp;
 	else {
 		werror("Error evaluating filter(%S), filter not found\n", self->name);
 		return 0;
