@@ -73,7 +73,7 @@ do_read_line(struct read_handler **h,
 	     struct abstract_read *read)
 {
 	CAST(log_reader, closure, *h);
-	UINT8 *eol;
+	UINT8 *eol, *start;
 	UINT32 length;
 	int n;
 	char sabuf[256];
@@ -106,34 +106,40 @@ do_read_line(struct read_handler **h,
 		closure->pos = 0;
 		return ST_OK | ST_GOON;
 	}
+	start = closure->buffer;
 	while (eol) {
 		/* eol points at the newline character. end points at the
 		 * character terminating the line, which may be a carriage
 		 * return preceeding the newline. */
 		UINT8 *end = eol;
 
-		while ((end > closure->buffer) && (end[-1] == '\r' || end[-1] == '\n' || end[-1] == 0))
+		while ((end > start) && (end[-1] == '\r' || end[-1] == '\n' || end[-1] == 0))
 			end--;
 
-		length = end - closure->buffer;
+		length = end - start;
 		
-		do_handle_line(closure, length, closure->buffer, salen ? (abstract_addr *) &sabuf : NULL , salen);
+		do_handle_line(closure, length, start, salen ? (abstract_addr *) &sabuf : NULL , salen);
 
+		start = end + 1;
+#if 0
 		{
 			/* Remove line from buffer */
 			/* Number of characters that have been processed */
 			UINT32 done = eol - closure->buffer + 1;
 			UINT32 left = closure->pos - done;
 
-			memcpy(closure->buffer, closure->buffer + done, left);
+			memmove(closure->buffer, closure->buffer + done, left);
 			closure->pos = left;
 		}
-		
-		eol = memchr(closure->buffer, '\0', closure->pos);
+#endif
+
+		eol = memchr(start, '\0', &closure->buffer[closure->pos] - start);
 		if (eol == NULL)
-			eol = memchr(closure->buffer, '\n', closure->pos);
+			eol = memchr(start, '\n', &closure->buffer[closure->pos] - start);
 
 	}
+	memmove(closure->buffer, start, &closure->buffer[closure->pos] - start);
+	closure->pos = &closure->buffer[closure->pos] - start;
 	return ST_OK | ST_GOON;
 }
 
