@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: sources.h,v 1.6 1999/11/22 18:26:16 bazsi Exp $
+ * $Id: sources.h,v 1.8 2000/03/03 14:43:20 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -58,7 +58,7 @@
          (name string)))
 */
 
-struct read_handler *make_log_reader(UINT32 userecv, struct log_handler *next);
+struct read_handler *make_log_reader(UINT32 dgram, struct log_handler *next);
 
 struct log_source_group *make_source_group(const char *name, struct log_source_driver *drvs);
 
